@@ -19,22 +19,22 @@
  */
 
 #include "test_courseresource.h"
-#include "resourcerepositorystub.h"
-#include "core/language.h"
-#include "core/unit.h"
-#include "core/phrase.h"
-#include "core/phonemegroup.h"
-#include "core/resources/courseresource.h"
 #include "../mocks/languagestub.h"
-#include <QTest>
+#include "core/language.h"
+#include "core/phonemegroup.h"
+#include "core/phrase.h"
+#include "core/resources/courseresource.h"
+#include "core/unit.h"
+#include "resourcerepositorystub.h"
 #include <QDebug>
-#include <QTemporaryFile>
-#include <QSignalSpy>
-#include <QIODevice>
+#include <QDomDocument>
 #include <QFile>
+#include <QIODevice>
+#include <QSignalSpy>
+#include <QTemporaryFile>
+#include <QTest>
 #include <QXmlSchema>
 #include <QXmlSchemaValidator>
-#include <QDomDocument>
 
 TestCourseResource::TestCourseResource()
 {
@@ -58,7 +58,7 @@ void TestCourseResource::loadCourseResource()
     languages.push_back(language);
     ResourceRepositoryStub repository(languages);
 
-    const QString courseDirectory = "data/courses/de/";
+    const QString courseDirectory = qApp->applicationDirPath() + "/../autotests/unittests/data/courses/de/";
     const QString courseFile = courseDirectory + "de.xml";
 
     auto course = CourseResource::create(QUrl::fromLocalFile(courseFile), &repository);
@@ -70,19 +70,19 @@ void TestCourseResource::loadCourseResource()
     QVERIFY(course->language() != nullptr);
     QCOMPARE(course->language()->id(), "de");
     QCOMPARE(course->units().count(), 1);
-    QCOMPARE(course->units().first()->course(), course.get());
+    QCOMPARE(course->units().first()->course(), course);
 
     const auto unit = course->units().first();
     QVERIFY(unit != nullptr);
     QCOMPARE(unit->id(), "1");
     QCOMPARE(unit->title(), QStringLiteral("Auf der Straße"));
     QCOMPARE(unit->foreignId(), "{dd60f04a-eb37-44b7-9787-67aaf7d3578d}");
-    QCOMPARE(unit->course(), course.get());
+    QCOMPARE(unit->course(), course);
 
-    QCOMPARE(unit->phraseList().count(), 3);
+    QCOMPARE(unit->phrases().count(), 3);
     // note: this test takes the silent assumption that phrases are added to the list in same
     //   order as they are defined in the file. This assumption should be made explicit or dropped
-    const auto firstPhrase = unit->phraseList().first();
+    const auto firstPhrase = unit->phrases().first();
     QVERIFY(firstPhrase != nullptr);
     QCOMPARE(firstPhrase->id(), "1");
     QCOMPARE(firstPhrase->foreignId(), "{3a4c1926-60d7-44c6-80d1-03165a641c75}");
@@ -109,12 +109,12 @@ void TestCourseResource::loadCourseResourceSkipIncomplete()
     QCOMPARE(course->file().toLocalFile(), courseFile);
     QCOMPARE(course->id(), "de");
     QCOMPARE(course->units().count(), 1);
-    QCOMPARE(course->units().first()->course(), course.get());
+    QCOMPARE(course->units().first()->course(), course);
 
     const auto unit = course->units().first();
     QVERIFY(unit != nullptr);
     QCOMPARE(unit->id(), "1");
-    QCOMPARE(unit->phraseList().count(), 2);
+    QCOMPARE(unit->phrases().count(), 2);
 }
 
 void TestCourseResource::unitAddAndRemoveHandling()
@@ -123,12 +123,12 @@ void TestCourseResource::unitAddAndRemoveHandling()
     std::shared_ptr<ILanguage> language(new LanguageStub("de"));
     ResourceRepositoryStub repository({language});
 
-    const QString courseDirectory = "data/courses/de/";
+    const QString courseDirectory = qApp->applicationDirPath() + "/../autotests/unittests/data/courses/de/";
     const QString courseFile = courseDirectory + "de.xml";
     auto course = CourseResource::create(QUrl::fromLocalFile(courseFile), &repository);
 
     // begin of test
-    std::unique_ptr<Unit> unit(new Unit);
+    auto unit = Unit::create();
     unit->setId("testunit");
     const int initialUnitNumber = course->units().count();
     QCOMPARE(initialUnitNumber, 1);
@@ -140,7 +140,7 @@ void TestCourseResource::unitAddAndRemoveHandling()
     QCOMPARE(course->units().count(), initialUnitNumber + 1);
     QCOMPARE(spyAboutToBeAdded.count(), 1);
     QCOMPARE(spyAdded.count(), 1);
-    QCOMPARE(sharedUnit->course(), course.get());
+    QCOMPARE(sharedUnit->course(), course);
 }
 
 void TestCourseResource::coursePropertyChanges()
@@ -149,7 +149,7 @@ void TestCourseResource::coursePropertyChanges()
     std::shared_ptr<ILanguage> language(new LanguageStub("de"));
     ResourceRepositoryStub repository({language});
 
-    const QString courseDirectory = "data/courses/de/";
+    const QString courseDirectory = qApp->applicationDirPath() + "/../autotests/unittests/data/courses/de/";
     const QString courseFile = courseDirectory + "de.xml";
     auto course = CourseResource::create(QUrl::fromLocalFile(courseFile), &repository);
 
