@@ -19,28 +19,29 @@
  */
 
 #include "test_editablecourseresource.h"
-#include "resourcerepositorystub.h"
+#include "../mocks/coursestub.h"
+#include "../mocks/languagestub.h"
 #include "core/language.h"
-#include "core/unit.h"
 #include "core/phrase.h"
 #include "core/resources/courseparser.h"
 #include "core/resources/editablecourseresource.h"
-#include "../mocks/languagestub.h"
-#include "../mocks/coursestub.h"
+#include "core/unit.h"
+#include "resourcerepositorystub.h"
 
-#include <memory>
-#include <QTest>
 #include <QDebug>
-#include <QTemporaryFile>
-#include <QSignalSpy>
-#include <QIODevice>
+#include <QDomDocument>
 #include <QFile>
+#include <QIODevice>
+#include <QSignalSpy>
+#include <QTemporaryFile>
+#include <QTest>
 #include <QXmlSchema>
 #include <QXmlSchemaValidator>
-#include <QDomDocument>
+#include <memory>
 
 TestEditableCourseResource::TestEditableCourseResource()
 {
+    qRegisterMetaType<std::shared_ptr<IEditableUnit>>("std::shared_ptr<IEditableUnit>");
 }
 
 void TestEditableCourseResource::init()
@@ -65,19 +66,19 @@ void TestEditableCourseResource::loadCourseResource()
     QVERIFY(course->language() != nullptr);
     QCOMPARE(course->language()->id(), "de");
     QCOMPARE(course->units().count(), 1);
-    QCOMPARE(course->units().first()->course(), course.get());
+    QCOMPARE(course->units().first()->course(), course);
 
     const auto unit = course->units().first();
     QVERIFY(unit != nullptr);
     QCOMPARE(unit->id(), "1");
     QCOMPARE(unit->title(), QStringLiteral("Auf der Straße"));
     QCOMPARE(unit->foreignId(), "{dd60f04a-eb37-44b7-9787-67aaf7d3578d}");
-    QCOMPARE(unit->course(), course.get());
+    QCOMPARE(unit->course(), course);
 
-    QCOMPARE(unit->phraseList().count(), 3);
+    QCOMPARE(unit->phrases().count(), 3);
     // note: this test takes the silent assumption that phrases are added to the list in same
     //   order as they are defined in the file. This assumption should be made explicit or dropped
-    const auto firstPhrase = unit->phraseList().first();
+    const auto firstPhrase = unit->phrases().first();
     QVERIFY(firstPhrase != nullptr);
     QCOMPARE(firstPhrase->id(), "1");
     QCOMPARE(firstPhrase->foreignId(), "{3a4c1926-60d7-44c6-80d1-03165a641c75}");
@@ -95,7 +96,7 @@ void TestEditableCourseResource::unitAddAndRemoveHandling()
     auto course = EditableCourseResource::create(QUrl::fromLocalFile(":/courses/de.xml"), &repository);
 
     // begin of test
-    std::unique_ptr<Unit> unit(new Unit);
+    auto unit = Unit::create();
     unit->setId("testunit");
     const int initialUnitNumber = course->units().count();
     QCOMPARE(initialUnitNumber, 1);
@@ -107,7 +108,40 @@ void TestEditableCourseResource::unitAddAndRemoveHandling()
     QCOMPARE(course->units().count(), initialUnitNumber + 1);
     QCOMPARE(spyAboutToBeAdded.count(), 1);
     QCOMPARE(spyAdded.count(), 1);
-    QCOMPARE(sharedUnit->course(), course.get());
+    QCOMPARE(sharedUnit->course(), course);
+}
+
+void TestEditableCourseResource::phraseAddAndRemoveHandling()
+{
+    //TODO simplify test by using empty course
+
+    // boilerplate
+    std::shared_ptr<ILanguage> language(new LanguageStub("de"));
+    ResourceRepositoryStub repository({language});
+    auto course = EditableCourseResource::create(QUrl::fromLocalFile(":/courses/de.xml"), &repository);
+    auto unit = Unit::create();
+    unit->setId("testunit");
+    course->addUnit(unit);
+
+    auto testPhrase = Phrase::create();
+    testPhrase->setId("testphrase");
+    unit->addPhrase(testPhrase, 0);
+    QCOMPARE(unit->phrases().count(), 1);
+    QCOMPARE(testPhrase->unit()->id(), "testunit");
+
+    // begin of test
+    {
+        QSignalSpy spy(course.get(), &IEditableCourse::unitChanged);
+        QVERIFY(course->createPhraseAfter(testPhrase.get()));
+        QCOMPARE(spy.count(), 1);
+        QCOMPARE(unit->phrases().count(), 2);
+    }
+    {
+        QSignalSpy spy(course.get(), &IEditableCourse::unitChanged);
+        QVERIFY(course->deletePhrase(testPhrase.get()));
+        QCOMPARE(spy.count(), 1);
+        QCOMPARE(unit->phrases().count(), 1);
+    }
 }
 
 void TestEditableCourseResource::coursePropertyChanges()
@@ -120,7 +154,7 @@ void TestEditableCourseResource::coursePropertyChanges()
     // id
     {
         const QString value = "newId";
-        QSignalSpy spy(course.get(), SIGNAL(idChanged()));
+        QSignalSpy spy(course.get(), &CourseResource::idChanged);
         QCOMPARE(spy.count(), 0);
         course->setId(value);
         QCOMPARE(course->id(), value);
@@ -188,7 +222,6 @@ void TestEditableCourseResource::fileLoadSaveCompleteness()
     QTemporaryFile outputFile;
     outputFile.open();
     course->exportToFile(QUrl::fromLocalFile(outputFile.fileName()));
-
     // note: this only works, since the resource manager not checks uniqueness of course ids!
     auto loadedCourse = EditableCourseResource::create(QUrl::fromLocalFile(outputFile.fileName()), &repository);
 
@@ -199,19 +232,19 @@ void TestEditableCourseResource::fileLoadSaveCompleteness()
     QVERIFY(course->title() == loadedCourse->title());
     QVERIFY(course->description() == loadedCourse->description());
     QVERIFY(course->language()->id() == loadedCourse->language()->id());
-    QVERIFY(course->units().count() == loadedCourse->units().count());
+    QCOMPARE(loadedCourse->units().count(), course->units().count());
 
     auto testUnit = course->units().constFirst();
     auto compareUnit = loadedCourse->units().constFirst();
-    QVERIFY(testUnit->id() == compareUnit->id());
-    QVERIFY(testUnit->foreignId() == compareUnit->foreignId());
-    QVERIFY(testUnit->title() == compareUnit->title());
-    QVERIFY(testUnit->phraseList().count() == compareUnit->phraseList().count());
+    QCOMPARE(compareUnit->id(), testUnit->id());
+    QCOMPARE(compareUnit->foreignId(), testUnit->foreignId());
+    QCOMPARE(compareUnit->title(), testUnit->title());
+    QCOMPARE(compareUnit->phrases().count(), testUnit->phrases().count());
 
-    Phrase *testPhrase = testUnit->phraseList().constFirst();
-    Phrase *comparePhrase = new Phrase(this);
+    std::shared_ptr<IPhrase> testPhrase = testUnit->phrases().constFirst();
+    std::shared_ptr<IPhrase> comparePhrase = Phrase::create();
     // note that this actually means that we DO NOT respect phrase orders by list order
-    for (Phrase *phrase : compareUnit->phraseList()) {
+    for (const auto &phrase : compareUnit->phrases()) {
         if (testPhrase->id() == phrase->id()) {
             comparePhrase = phrase;
             break;
@@ -307,7 +340,7 @@ void TestEditableCourseResource::modifiedStatus()
         course->exportToFile(QUrl::fromLocalFile(outputFile.fileName()));
         auto loadedCourse = EditableCourseResource::create(QUrl::fromLocalFile(outputFile.fileName()), &repository);
         QCOMPARE(loadedCourse->isModified(), false);
-        std::unique_ptr<Unit> unit(new Unit);
+        auto unit = Unit::create();
         unit->setId("testunit");
         loadedCourse->addUnit(std::move(unit));
         QCOMPARE(loadedCourse->isModified(), true);
@@ -324,13 +357,13 @@ void TestEditableCourseResource::skeletonUpdate()
     QCOMPARE(course->units().count(), 1);
 
     // create skeleton stub
-    auto importPhrase = new Phrase;
+    auto importPhrase = Phrase::create();
     importPhrase->setId("importPhraseId");
     importPhrase->setText("phraseText");
-    importPhrase->setType(Phrase::Sentence);
-    auto importUnit = std::shared_ptr<Unit>(new Unit);
+    importPhrase->setType(IPhrase::Type::Sentence);
+    auto importUnit = Unit::create();
     importUnit->setId("importId");
-    importUnit->addPhrase(importPhrase);
+    importUnit->addPhrase(importPhrase, importUnit->phrases().size());
     auto skeleton = CourseStub::create(language, {importUnit});
 
     // test import
@@ -348,8 +381,8 @@ void TestEditableCourseResource::skeletonUpdate()
         QCOMPARE(importedUnit->foreignId(), importUnit->id());
         QCOMPARE(importedUnit->id(), importUnit->id());
         QCOMPARE(importedUnit->title(), importUnit->title());
-        QCOMPARE(importedUnit->phraseList().count(), 1);
-        auto importedPhrase = importedUnit->phraseList().first();
+        QCOMPARE(importedUnit->phrases().count(), 1);
+        auto importedPhrase = importedUnit->phrases().first();
         QCOMPARE(importedPhrase->id(), importPhrase->id());
         QCOMPARE(importedPhrase->foreignId(), importPhrase->id());
         QCOMPARE(importedPhrase->text(), importPhrase->text());
