@@ -20,21 +20,21 @@
  */
 
 #include "courseresource.h"
-#include "courseparser.h"
+#include "core/iresourcerepository.h"
 #include "core/language.h"
-#include "core/unit.h"
 #include "core/phoneme.h"
 #include "core/phonemegroup.h"
-#include "core/iresourcerepository.h"
+#include "core/unit.h"
+#include "courseparser.h"
 
-#include <memory>
-#include <QQmlEngine>
-#include <QXmlSchema>
-#include <QXmlStreamReader>
+#include <QDir>
 #include <QDomDocument>
 #include <QFile>
 #include <QFileInfo>
-#include <QDir>
+#include <QQmlEngine>
+#include <QXmlSchema>
+#include <QXmlStreamReader>
+#include <memory>
 
 #include "artikulate_debug.h"
 
@@ -47,7 +47,7 @@ public:
     void loadCourse(CourseResource *parent, bool skipIncomplete);
 
     std::weak_ptr<ICourse> m_self;
-    IResourceRepository *m_repository{ nullptr };
+    IResourceRepository *m_repository {nullptr};
     QUrl m_file;
     QString m_identifier;
     QString m_foreignId;
@@ -57,8 +57,8 @@ public:
     QString m_i18nTitle;
     QString m_description;
     QVector<std::shared_ptr<Unit>> m_units;
-    bool m_courseLoaded{ false }; ///<! indicates if course was completely parsed
-    bool m_skipIncomplete{ false };
+    bool m_courseLoaded {false}; ///<! indicates if course was completely parsed
+    bool m_skipIncomplete {false};
 };
 
 CourseResourcePrivate::~CourseResourcePrivate() = default;
@@ -80,7 +80,7 @@ void CourseResourcePrivate::loadCourse(CourseResource *parent, bool skipIncomple
     QVector<std::shared_ptr<Phoneme>> phonemes = m_language->phonemes();
     auto units = CourseParser::parseUnits(m_file, phonemes, skipIncomplete);
     for (auto &unit : units) {
-        if (!skipIncomplete || unit->phraseList().count() > 0) {
+        if (!skipIncomplete || unit->phrases().count() > 0) {
             parent->addUnit(std::move(unit));
         }
     }
@@ -95,6 +95,7 @@ std::shared_ptr<CourseResource> CourseResource::create(const QUrl &path, IResour
 
 void CourseResource::setSelf(std::shared_ptr<ICourse> self)
 {
+    Q_ASSERT(d->m_self.expired());
     d->m_self = self;
 }
 
@@ -127,7 +128,7 @@ CourseResource::CourseResource(const QUrl &path, IResourceRepository *repository
                 d->m_foreignId = xml.readElementText();
                 continue;
             }
-            //TODO i18nTitle must be implemented, currently missing and hence not parsed
+            // TODO i18nTitle must be implemented, currently missing and hence not parsed
             if (xml.name() == "title") {
                 d->m_title = xml.readElementText();
                 d->m_i18nTitle = d->m_title;
@@ -143,14 +144,7 @@ CourseResource::CourseResource(const QUrl &path, IResourceRepository *repository
             }
 
             // quit reading when basic elements are read
-            if (!d->m_identifier.isEmpty()
-                && !d->m_title.isEmpty()
-                && !d->m_i18nTitle.isEmpty()
-                && !d->m_description.isEmpty()
-                && !d->m_languageId.isEmpty()
-                && !d->m_foreignId.isEmpty()
-            )
-            {
+            if (!d->m_identifier.isEmpty() && !d->m_title.isEmpty() && !d->m_i18nTitle.isEmpty() && !d->m_description.isEmpty() && !d->m_languageId.isEmpty() && !d->m_foreignId.isEmpty()) {
                 break;
             }
         }
@@ -256,6 +250,14 @@ std::shared_ptr<ILanguage> CourseResource::language() const
     return d->m_language;
 }
 
+QString CourseResource::languageTitle() const
+{
+    if (d->m_language) {
+        return d->m_language->title();
+    }
+    return QString();
+}
+
 void CourseResource::setLanguage(std::shared_ptr<ILanguage> language)
 {
     if (d->m_language == language) {
@@ -265,10 +267,10 @@ void CourseResource::setLanguage(std::shared_ptr<ILanguage> language)
     emit languageChanged();
 }
 
-std::shared_ptr<Unit> CourseResource::addUnit(std::unique_ptr<Unit> unit)
+std::shared_ptr<Unit> CourseResource::addUnit(std::shared_ptr<Unit> unit)
 {
     std::shared_ptr<Unit> storedUnit(std::move(unit));
-    storedUnit->setCourse(this);
+    storedUnit->setCourse(self());
     emit unitAboutToBeAdded(storedUnit, d->m_units.count() - 1);
     d->m_units.append(storedUnit);
     emit unitAdded();
