@@ -24,7 +24,6 @@
 #include "core/phrase.h"
 #include "core/unit.h"
 #include "courseparser.h"
-
 #include <KLocalizedString>
 #include <KTar>
 #include <QDir>
@@ -34,6 +33,7 @@
 #include <QObject>
 #include <QQmlEngine>
 #include <QUuid>
+#include <memory>
 
 EditableCourseResource::EditableCourseResource(const QUrl &path, IResourceRepository *repository)
     : IEditableCourse()
@@ -41,25 +41,21 @@ EditableCourseResource::EditableCourseResource(const QUrl &path, IResourceReposi
 {
     QQmlEngine::setObjectOwnership(this, QQmlEngine::CppOwnership);
 
-    for (auto unit : m_course->units()) {
-        unit->setCourse(this);
-    }
-
     connect(m_course.get(), &ICourse::unitAboutToBeAdded, this, &ICourse::unitAboutToBeAdded);
     connect(m_course.get(), &ICourse::unitAdded, this, &ICourse::unitAdded);
     connect(m_course.get(), &CourseResource::idChanged, this, &EditableCourseResource::idChanged);
-    connect(m_course.get(), &CourseResource::foreignIdChanged, this,
-        &EditableCourseResource::foreignIdChanged);
-    connect(
-        m_course.get(), &CourseResource::titleChanged, this, &EditableCourseResource::titleChanged);
-    connect(m_course.get(), &CourseResource::descriptionChanged, this,
-        &EditableCourseResource::descriptionChanged);
-    connect(m_course.get(), &CourseResource::languageChanged, this,
-        &EditableCourseResource::languageChanged);
+    connect(m_course.get(), &CourseResource::foreignIdChanged, this, &EditableCourseResource::foreignIdChanged);
+    connect(m_course.get(), &CourseResource::titleChanged, this, &EditableCourseResource::titleChanged);
+    connect(m_course.get(), &CourseResource::descriptionChanged, this, &EditableCourseResource::descriptionChanged);
+    connect(m_course.get(), &CourseResource::languageChanged, this, &EditableCourseResource::languageChanged);
+
+    for (auto &unit : m_course->units()) {
+        connect(unit.get(), &Unit::phrasesChanged, this, &IEditableCourse::unitChanged);
+        connect(unit.get(), &Unit::modified, this, &EditableCourseResource::markModified);
+    }
 }
 
-std::shared_ptr<EditableCourseResource> EditableCourseResource::create(
-    const QUrl &path, IResourceRepository *repository)
+std::shared_ptr<EditableCourseResource> EditableCourseResource::create(const QUrl &path, IResourceRepository *repository)
 {
     std::shared_ptr<EditableCourseResource> course(new EditableCourseResource(path, repository));
     course->setSelf(course);
@@ -84,14 +80,20 @@ void EditableCourseResource::setId(QString id)
     }
 }
 
-QString EditableCourseResource::foreignId() const { return m_course->foreignId(); }
+QString EditableCourseResource::foreignId() const
+{
+    return m_course->foreignId();
+}
 
 void EditableCourseResource::setForeignId(QString foreignId)
 {
     m_course->setForeignId(std::move(foreignId));
 }
 
-QString EditableCourseResource::title() const { return m_course->title(); }
+QString EditableCourseResource::title() const
+{
+    return m_course->title();
+}
 
 void EditableCourseResource::setTitle(QString title)
 {
@@ -101,7 +103,10 @@ void EditableCourseResource::setTitle(QString title)
     }
 }
 
-QString EditableCourseResource::i18nTitle() const { return m_course->i18nTitle(); }
+QString EditableCourseResource::i18nTitle() const
+{
+    return m_course->i18nTitle();
+}
 
 void EditableCourseResource::setI18nTitle(QString i18nTitle)
 {
@@ -111,7 +116,10 @@ void EditableCourseResource::setI18nTitle(QString i18nTitle)
     }
 }
 
-QString EditableCourseResource::description() const { return m_course->description(); }
+QString EditableCourseResource::description() const
+{
+    return m_course->description();
+}
 
 void EditableCourseResource::setDescription(QString description)
 {
@@ -121,7 +129,15 @@ void EditableCourseResource::setDescription(QString description)
     }
 }
 
-std::shared_ptr<ILanguage> EditableCourseResource::language() const { return m_course->language(); }
+std::shared_ptr<ILanguage> EditableCourseResource::language() const
+{
+    return m_course->language();
+}
+
+QString EditableCourseResource::languageTitle() const
+{
+    return m_course->languageTitle();
+}
 
 void EditableCourseResource::setLanguage(std::shared_ptr<ILanguage> language)
 {
@@ -173,38 +189,43 @@ bool EditableCourseResource::exportToFile(const QUrl &filePath) const
     // TODO port to KSaveFile
     QFile file(filePath.toLocalFile());
     if (!file.open(QIODevice::WriteOnly)) {
-        qCWarning(ARTIKULATE_LOG())
-            << "Unable to open file " << file.fileName() << " in write mode, aborting.";
+        qCWarning(ARTIKULATE_LOG()) << "Unable to open file " << file.fileName() << " in write mode, aborting.";
         return false;
     }
 
-    file.write(CourseParser::serializedDocument(m_course.get(), false).toByteArray());
+    file.write(CourseParser::serializedDocument(self(), false).toByteArray());
     return true;
 }
 
-std::shared_ptr<Unit> EditableCourseResource::addUnit(std::unique_ptr<Unit> unit)
+std::shared_ptr<Unit> EditableCourseResource::addUnit(std::shared_ptr<Unit> unit)
 {
     m_modified = true;
-    auto sharedUnit = m_course->addUnit(std::move(unit));
-    sharedUnit->setCourse(this);
-    return sharedUnit;
+    m_course->addUnit(unit);
+    unit->setCourse(self());
+    connect(unit.get(), &Unit::phrasesChanged, this, &IEditableCourse::unitChanged);
+    return unit;
 }
 
-QVector<std::shared_ptr<Unit>> EditableCourseResource::units() { return m_course->units(); }
+QVector<std::shared_ptr<Unit>> EditableCourseResource::units()
+{
+    if (!m_unitsLoaded) {
+        for (auto &unit : m_course->units()) {
+            unit->setCourse(self());
+        }
+        m_unitsLoaded = true;
+    }
+    return m_course->units();
+}
 
 void EditableCourseResource::updateFrom(std::shared_ptr<ICourse> skeleton)
 {
     for (auto skeletonUnit : skeleton->units()) {
-
         // find matching unit or create one
         std::shared_ptr<Unit> matchingUnit;
-        auto it = std::find_if(m_course->units().cbegin(), m_course->units().cend(),
-            [skeletonUnit](std::shared_ptr<Unit> compareUnit) {
-                return compareUnit->foreignId() == skeletonUnit->id();
-            });
+        auto it = std::find_if(m_course->units().cbegin(), m_course->units().cend(), [skeletonUnit](std::shared_ptr<Unit> compareUnit) { return compareUnit->foreignId() == skeletonUnit->id(); });
         if (it == m_course->units().cend()) {
             // import complete unit
-            auto importUnit = std::unique_ptr<Unit>(new Unit);
+            auto importUnit = Unit::create();
             importUnit->setId(skeletonUnit->id());
             importUnit->setForeignId(skeletonUnit->id());
             importUnit->setTitle(skeletonUnit->title());
@@ -214,21 +235,18 @@ void EditableCourseResource::updateFrom(std::shared_ptr<ICourse> skeleton)
         }
 
         // import phrases
-        for (auto skeletonPhrase : skeletonUnit->phraseList()) {
-            auto it = std::find_if(matchingUnit->phraseList().cbegin(),
-                matchingUnit->phraseList().cend(), [skeletonPhrase](Phrase *comparePhrase) {
-                    return comparePhrase->foreignId() == skeletonPhrase->id();
-                });
-            if (it == matchingUnit->phraseList().cend()) {
+        for (auto skeletonPhrase : skeletonUnit->phrases()) {
+            auto it = std::find_if(matchingUnit->phrases().cbegin(), matchingUnit->phrases().cend(), [skeletonPhrase](std::shared_ptr<IPhrase> comparePhrase) { return comparePhrase->foreignId() == skeletonPhrase->id(); });
+            if (it == matchingUnit->phrases().cend()) {
                 // import complete Phrase
-                Phrase *importPhrase = new Phrase(matchingUnit.get());
+                std::shared_ptr<Phrase> importPhrase = Phrase::create();
                 importPhrase->setId(skeletonPhrase->id());
                 importPhrase->setForeignId(skeletonPhrase->id());
                 importPhrase->setText(skeletonPhrase->text());
                 importPhrase->seti18nText(skeletonPhrase->i18nText());
                 importPhrase->setType(skeletonPhrase->type());
-                importPhrase->setUnit(matchingUnit.get());
-                matchingUnit->addPhrase(importPhrase);
+                importPhrase->setUnit(matchingUnit);
+                matchingUnit->addPhrase(importPhrase, matchingUnit->phrases().size());
             }
         }
     }
@@ -236,7 +254,10 @@ void EditableCourseResource::updateFrom(std::shared_ptr<ICourse> skeleton)
     qCInfo(ARTIKULATE_LOG()) << "Update performed!";
 }
 
-bool EditableCourseResource::isModified() const { return m_modified; }
+bool EditableCourseResource::isModified() const
+{
+    return m_modified;
+}
 
 Unit *EditableCourseResource::createUnit()
 {
@@ -252,8 +273,8 @@ Unit *EditableCourseResource::createUnit()
     }
 
     // create unit
-    std::unique_ptr<Unit> unit(new Unit(this));
-    unit->setCourse(this);
+    std::shared_ptr<Unit> unit = Unit::create();
+    unit->setCourse(self());
     unit->setId(id);
     unit->setTitle(i18n("New Unit"));
     auto sharedUnit = addUnit(std::move(unit));
@@ -261,12 +282,31 @@ Unit *EditableCourseResource::createUnit()
     return sharedUnit.get();
 }
 
-Phrase *EditableCourseResource::createPhrase(Unit *unit)
+bool EditableCourseResource::createPhraseAfter(IPhrase *previousPhrase)
 {
+    std::shared_ptr<Unit> parentUnit = units().last();
+    if (previousPhrase) {
+        for (const auto &unit : units()) {
+            if (previousPhrase->unit()->id() == unit->id()) {
+                parentUnit = unit;
+                break;
+            }
+        }
+    }
+
+    // find index
+    int index = parentUnit->phrases().size();
+    for (int i = 0; i < parentUnit->phrases().size(); ++i) {
+        if (parentUnit->phrases().at(i)->id() == previousPhrase->id()) {
+            index = i;
+            break;
+        }
+    }
+
     // find globally unique phrase id inside course
     QStringList phraseIds;
     for (auto unit : m_course->units()) {
-        for (auto *phrase : unit->phraseList()) {
+        for (auto &phrase : unit->phrases()) {
             phraseIds.append(phrase->id());
         }
     }
@@ -277,12 +317,37 @@ Phrase *EditableCourseResource::createPhrase(Unit *unit)
     }
 
     // create unit
-    Phrase *phrase = new Phrase(this);
+    std::shared_ptr<Phrase> phrase = Phrase::create();
     phrase->setId(id);
     phrase->setText(QLatin1String(""));
-    phrase->setType(Phrase::Word);
+    phrase->setType(IPhrase::Type::Word);
+    parentUnit->addPhrase(phrase, index + 1);
 
-    unit->addPhrase(phrase);
+    qCDebug(ARTIKULATE_CORE()) << "Created phrase at index" << index + 1;
 
-    return phrase;
+    return true;
+}
+
+bool EditableCourseResource::deletePhrase(IPhrase *phrase)
+{
+    Q_ASSERT(phrase);
+    if (!phrase) {
+        return false;
+    }
+    auto unitId = phrase->unit()->id();
+    for (auto &unit : units()) {
+        if (unit->id() == unitId) {
+            unit->removePhrase(phrase->self());
+            return true;
+        }
+    }
+    return false;
+}
+
+void EditableCourseResource::markModified()
+{
+    if (!m_modified) {
+        m_modified = true;
+        emit modifiedChanged(true);
+    }
 }
