@@ -22,18 +22,18 @@
 #define EDITABLECOURSERESOURCE_H
 
 #include "artikulatecore_export.h"
-#include "courseresource.h"
 #include "core/icourse.h"
 #include "core/ieditablecourse.h"
-
-#include <memory>
+#include "core/ieditableunit.h"
+#include "courseresource.h"
 #include <QObject>
 #include <QVector>
+#include <memory>
 
 class IResourceRepository;
 class Course;
 class Unit;
-class Phrase;
+class IPhrase;
 class QString;
 class QDomDocument;
 
@@ -90,19 +90,21 @@ public:
      * \return language identifier of this course
      */
     std::shared_ptr<ILanguage> language() const override;
+    QString languageTitle() const override;
     void setLanguage(std::shared_ptr<ILanguage> language) override;
     bool sync() override;
     bool exportToFile(const QUrl &filePath) const override;
 
-    std::shared_ptr<Unit> addUnit(std::unique_ptr<Unit> unit) override;
+    std::shared_ptr<Unit> addUnit(std::shared_ptr<Unit> unit) override;
     QVector<std::shared_ptr<Unit>> units() override;
     void updateFrom(std::shared_ptr<ICourse> course) override;
     bool isModified() const override;
     QUrl file() const override;
     std::shared_ptr<IEditableCourse> self() const override;
 
-    Q_INVOKABLE Unit * createUnit();
-    Q_INVOKABLE Phrase * createPhrase(Unit *unit);
+    Q_INVOKABLE Unit *createUnit();
+    Q_INVOKABLE bool createPhraseAfter(IPhrase *previousPhrase) override;
+    Q_INVOKABLE bool deletePhrase(IPhrase *phrase) override;
 
 Q_SIGNALS:
     void idChanged();
@@ -112,6 +114,9 @@ Q_SIGNALS:
     void descriptionChanged();
     void languageChanged();
 
+private Q_SLOTS:
+    void markModified();
+
 private:
     Q_DISABLE_COPY(EditableCourseResource)
     /**
@@ -119,7 +124,8 @@ private:
      */
     explicit EditableCourseResource(const QUrl &path, IResourceRepository *repository);
     void setSelf(std::shared_ptr<ICourse> self) override;
-    bool m_modified{ false };
+    mutable bool m_unitsLoaded {false}; ///< parsing of all units is postponed until needed, this variable indicates if they are read
+    bool m_modified {false};
     const std::unique_ptr<CourseResource> m_course;
 };
 
